from .assets import get_logo_path_low_res
from . import __version__
from pathlib import Path
import tkinter

class About(tkinter.Toplevel):
    def __init__(self) -> None:
        super().__init__()

        self.set_widgets()

    def set_widgets(self) -> None:
        self.title('About YAQN')
        self.resizable(False, False)

        # Set the logo of YAQN as the first half of the window
        self.image_frame: tkinter.Frame = tkinter.Frame(self)
        self.image_frame.pack(side=tkinter.TOP)

        # Define the logo as a tkinter image object
        logo_path: Path = get_logo_path_low_res()
        self.logo_image: tkinter.PhotoImage = tkinter.PhotoImage(file=logo_path)

        # Put the image object to a label
        self.image_label: tkinter.Label = tkinter.Label(
            self,
            image=self.logo_image
        )
        self.image_label.pack(
            padx=50,
            pady=(10, 5)
        )

        # Set the texts
        self.text_frame: tkinter.Frame = tkinter.Frame(self)
        self.text_frame.pack()

        # Set the title of the app and make it bold
        font_title: tkinter.font.Font = tkinter.font.Font(weight='bold')

        self.title: tkinter.Label = tkinter.Label(
            self.text_frame,
            text='YAQN',
            font=font_title
        )
        self.title.pack()

        # Set the subtitle
        self.subtitle: tkinter.Label = tkinter.Label(
            self.text_frame,
            text='Yet Another Quick Note'
        )
        self.subtitle.pack()

        # Set the version number and make it smaller
        font_little: tkinter.font.Font = tkinter.font.Font(size=12)

        self.version: tkinter.Label = tkinter.Label(
            self.text_frame,
            text=f'Version {__version__}',
            font=font_little
        )
        self.version.pack(
            pady=(0, 5)
        )

        # Set the created by section
        self.created_by_frame: tkinter.Frame = tkinter.Frame(self)
        self.created_by_frame.pack(side=tkinter.BOTTOM)

        self.kutu_label: tkinter.Label = tkinter.Label(
            self.created_by_frame,
            text='Created with ♥ by\nKutu (@kutu-dev)',
            font=font_little
        )
        self.kutu_label.pack()

        self.other_authors_label: tkinter.Label = tkinter.Label(
            self.created_by_frame,
            text='App icon created by\n\'vladlucha\' in MacOS Icons',
            font=font_little
        )
        self.other_authors_label.pack(
            pady=(0, 25)
        )


from pathlib import Path
from datetime import datetime
from .config import config_data

def save_note(note_title: str, note_data: str, config_data: config_data):
        notes_dir_path: Path = config_data.notes_dir_path
        extension: str = config_data.extension
        no_whitespaces: bool = config_data.no_whitespaces
        no_uppercase: bool = config_data.no_uppercase
        no_firstline: bool = config_data.no_firstline

        # Create the notes path
        notes_dir_path.mkdir(parents=True, exist_ok=True)

        # Check if the first line in the textbox is valid as a filename
        note_filename: str
        if note_title != '':
            note_filename = note_title
        else:
            note_filename = datetime.now().strftime('%H%M%S-%d%m%Y')

        if no_whitespaces:
            # Remove all whitespaces and split the words with hyphens
            note_filename = '-'.join(note_filename.split())

        if no_uppercase:
            note_filename = note_filename.lower()

        if no_firstline:
            # Split the text of the note in lines, discard the first line and convert to string
            note_list_modified: list[str] = note_data.split('\n')[1:]
            note_data = str().join(note_list_modified)

        # Get the note path and check if its valid
        note_path: Path = Path(notes_dir_path, f'{note_filename}.{extension}')
        note_path = check_note_path(note_path)

        # Get the textbox data and save it
        note:str = note_data

        note_path.touch()
        with open(note_path, 'w') as file:
            file.write(note)

def check_note_path(note_path: Path) -> Path:
    if not note_path.is_file():
        return note_path
    
    datetime_now: str = datetime.now().strftime('%H%M%S-%d%m%Y')
    new_filename: str = f'{note_path.stem}-{datetime_now}{note_path.suffix}'

    return check_note_path(Path(note_path.parent, new_filename))
